==> migrate_wizard-2.0.7-alpha1.tar.gz: migrate_wizard/src/Controller/DatabaseController.php <==
<?php
/**
 * @file
 * Handles the automatic generation of migration YAML files.
 *
 * Migrate Wizard - Facilitates migration from Drupal 7 by mapping fields and content types
 * through an interface, without the need for programming.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Migrate Wizard. If not, see <https://www.gnu.org/licenses/>.
 *
 * Author: Carlos Romero Álvarez
 */

namespace Drupal\migrate_wizard\Controller;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Url;
use Drupal\migrate_wizard\MWManageDataService;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * A controller to interact with origin node entities.
 */
class DatabaseController extends ControllerBase {

  /**
   * The MWManageDataService.
   *
   * @var \Drupal\migrate_wizard\MWManageDataService
   */
  protected $mwManageDataService;
  protected $current_mw_database;

  /**
   * {@inheritdoc}
   */
  public function __construct(MWManageDataService $mw_manage_data_service, RequestStack $request_stack) {
    $this->mwManageDataService = $mw_manage_data_service;
    $this->current_mw_database = $request_stack->getCurrentRequest()->get('mw_database');
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new self(
      $container->get('migrate_wizard.migrate_wizard_manage_data_service'),
      $container->get('request_stack')
    );
  }

 public function databaseSelector($type = null): \Drupal\Core\StringTranslation\TranslatableMarkup
  {
    return $this->t('Content types from database '.$this->current_mw_database->id);
  }
  /**
   * {@inheritdoc}
   */
  public function selectDatabase() {

    $url = Url::fromRoute($_REQUEST["redirect"],
        ['mw_database' => $_REQUEST["database_selected"]]);

   return $this->redirect($url->getRouteName(), $url->getRouteParameters());
  }
}

==> migrate_wizard-2.0.9-alpha1.tar.gz: migrate_wizard/src/Controller/DatabaseController.php <==
<?php
/**
 * @file
 * Handles the automatic generation of migration YAML files.
 *
 * Migrate Wizard - Facilitates migration from Drupal 7 by mapping fields and content types
 * through an interface, without the need for programming.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Migrate Wizard. If not, see <https://www.gnu.org/licenses/>.
 *
 * Author: Carlos Romero Álvarez
 */

namespace Drupal\migrate_wizard\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Url;
use Drupal\migrate_wizard\MWManageDataService;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * A controller to interact with origin node entities.
 */
class DatabaseController extends ControllerBase {

  protected $current_mw_database;

  /**
   * The MWManageDataService.
   *
   * @var MWManageDataService
   */
  protected $mwManageDataService;

  /**
   * {@inheritdoc}
   */
  public function __construct(MWManageDataService $mw_manage_data_service, RequestStack $request_stack) {
    $this->mwManageDataService = $mw_manage_data_service;
    $this->current_mw_database = $request_stack->getCurrentRequest()->get('mw_database');
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new self(
      $container->get('migrate_wizard.migrate_wizard_manage_data_service'),
      $container->get('request_stack')
    );
  }

  public function databaseSelector($type = NULL): \Drupal\Core\StringTranslation\TranslatableMarkup {
    return $this->t('Content types from database ' . $this->current_mw_database->id);
  }
}
